/*

Das Prinzip von Hashtabellen ist, dass Daten so in einem Array abgelegt werden, dass ihr In-
dex durch den geuschten Wert mittels einer Hashfunktion bestimmt werden kann. Dadurch
kann das Entfernen und Ablegen von Daten - bei geeignet großem Array und geeigneter
Hashfunktion - mit konstantem Aufwand erledigt werden. Da der Fall auftreten kann, dass
zwei Datensätze den gleichen Hash-Wert haben, darf das Array die Datensätze nicht direkt
beherbergen, sondern muss Listen beinhalten, deren Elemente dann jeweils den gleichen
Hashwert haben.
Hier ein Beispiel für eine Hashfunktion, die Ihr verwenden könnt:

*/

#define HASHSTART 5381

static unsigned int hashadd(int hashval, unsigned char ch) {
   hashval += hashval << 5;
   return hashval ^ ch;
}

static unsigned int compute_hash(const char* buf) {
   int hashval = HASHSTART;
   while (*buf) {
      hashval = hashadd(hashval, *buf++);
   }
   return hashval;
}

/*
Der Schlüssel, aus dem der Hashwert berechnet wird, ist hier also einfach ein C-String. Der
so errechnete Wert kann (modulo Größe des Arrays) als Index verwendet werden.
*/
